# coding: utf-8
from spyne.decorator import rpc
from spyne.model.primitive import String, Date, Boolean

import importlib

from .utils import validate_dou_info_request
from .constants import DECL_INFO_REPORT_MODULES
from .types import GetDouInfoResponse, GetDouListResponse


@rpc(
    Date, String,
    _in_variable_names=dict(
        decl_date='declDate',
        report_code='requestType',
    ),
    _returns=GetDouInfoResponse,
    _out_message_name='GetDouInfoResponse',
)
def GetDouInfo(ctx, decl_date, report_code):
    validate_dou_info_request(ctx, decl_date, report_code)
    logic = importlib.import_module(DECL_INFO_REPORT_MODULES[report_code])

    kwargs = dict(
        ctx=ctx,
        report_code=report_code,
        decl_date=decl_date)

    out_format = 'xml'
    file_name = '.'.join((report_code, out_format))
    content = logic.get_content(**kwargs)

    return GetDouInfoResponse.create(file_name, content)


@rpc(_returns=GetDouListResponse,
    _out_message_name='GetDouListResponse',
)
def GetDouList(ctx):
    from .dou_list import logic

    out_format = 'xml'
    file_name = '.'.join(('GetDouList', out_format))
    content = logic.get_content()
    return GetDouListResponse.create(file_name, content)
